function plot_major_planets

%% Mercury
handles.coe.a = 0.38709893;
handles.coe.e = 0.20563069;
handles.coe.inc = 7.00487;
handles.coe.omega = 48.33167;
handles.coe.w = 77.45645;
handles.coe.v = 252.25084;
handles.coe.r = 0.00465047;

a = handles.coe.a;
e = handles.coe.e;
inc = handles.coe.inc;
omega = handles.coe.omega;
w = handles.coe.w;
v = handles.coe.v;
r = handles.coe.r;

[x,y,z] = orbit(a, e, omega*pi/180, inc*pi/180, w*pi/180);
[xv,yv,zv] = trueanomaly(a,e,omega*pi/180,inc*pi/180,w*pi/180,v*pi/180);
[xp,yp,zp] = planet(r,20); % earth radius ( km )

orbit_color = [0,0.5,0];

plot3(x,y,z,'Color',orbit_color,'Linewidth',2); % direct

axis equal
hold on

plot3(xv,yv,zv,'Color',[0,0.5,0],'MarkerFaceColor',[0,0.5,0],'Marker','o','Linewidth',2); % plot true anomaly
surf(xp,yp,zp,'EdgeAlpha',0.4);   % plot the planet
colormap([0  0.5  0]);

scale = 2;
axis([-scale*a scale*a -scale*a scale*a -scale*a scale*a])


% Get Axis properties 
axis_data = get(gca);
xmin = axis_data.XLim(1);
xmax = axis_data.XLim(2);
ymin = axis_data.YLim(1);
ymax = axis_data.YLim(2);
zmin = axis_data.ZLim(1);
zmax = axis_data.ZLim(2);

% I, J ,K vectors
% plot3([xmin,xmax],[0 0],[0 0],'black','Linewidth',1); plot3(xmax,0,0,'black>','Linewidth',1.5);
% plot3([0 0],[ymin,ymax],[0 0],'black','Linewidth',1); plot3(0,ymax,0,'blue>','Linewidth',1.5);
% plot3([0 0],[0 0],[zmin,zmax],'black','Linewidth',1); plot3(0,0,zmax,'red^','Linewidth',1.5);

% right ascending node line plot
xomega_max = xmax*cos(omega*pi/180);
xomega_min = xmin*cos(omega*pi/180);
yomega_max = ymax*sin(omega*pi/180);
yomega_min = ymin*sin(omega*pi/180);

xlabel('I');
ylabel('J');
zlabel('K');

% plot3([xomega_min xomega_max], [yomega_min yomega_max], [0 0], 'g','Linewidth',1.5);

% add equatorial plan
% xe = [xmin xmax;xmin xmax]; ye = [ymax ymax;ymin ymin]; ze = [0 0; 0 0];
% eq_alpha = 0.3; % transparancy 
% mesh(xe,ye,ze,'FaceAlpha',eq_alpha,'FaceColor',[0.753,0.753,0.753]);

grid on

%% Venus
handles.coe.a = 0.72333199;
handles.coe.e = 0.00677323;
handles.coe.inc = 3.39471;
handles.coe.omega = 76.68069;
handles.coe.w = 131.53298;
handles.coe.v = 181.97973;
handles.coe.r = 0.00465047;

a = handles.coe.a;
e = handles.coe.e;
inc = handles.coe.inc;
omega = handles.coe.omega;
w = handles.coe.w;
v = handles.coe.v;
r = handles.coe.r;

[x,y,z] = orbit(a, e, omega*pi/180, inc*pi/180, w*pi/180);
[xv,yv,zv] = trueanomaly(a,e,omega*pi/180,inc*pi/180,w*pi/180,v*pi/180);
[xp,yp,zp] = planet(r,20); % earth radius ( km )

plot3(x,y,z,'Color',orbit_color,'Linewidth',2); % direct

axis equal
hold on

plot3(xv,yv,zv,'Color',[0,0.5,0],'MarkerFaceColor',[0,0.5,0],'Marker','o','Linewidth',2); % plot true anomaly
surf(xp,yp,zp,'EdgeAlpha',0.4);   % plot the planet
colormap([0  0.5  0]);

scale = 2;
axis([-scale*a scale*a -scale*a scale*a -scale*a scale*a])


% Get Axis properties 
axis_data = get(gca);
xmin = axis_data.XLim(1);
xmax = axis_data.XLim(2);
ymin = axis_data.YLim(1);
ymax = axis_data.YLim(2);
zmin = axis_data.ZLim(1);
zmax = axis_data.ZLim(2);

% I, J ,K vectors
% plot3([xmin,xmax],[0 0],[0 0],'black','Linewidth',1); plot3(xmax,0,0,'black>','Linewidth',1.5);
% plot3([0 0],[ymin,ymax],[0 0],'black','Linewidth',1); plot3(0,ymax,0,'blue>','Linewidth',1.5);
% plot3([0 0],[0 0],[zmin,zmax],'black','Linewidth',1); plot3(0,0,zmax,'red^','Linewidth',1.5);

% right ascending node line plot
xomega_max = xmax*cos(omega*pi/180);
xomega_min = xmin*cos(omega*pi/180);
yomega_max = ymax*sin(omega*pi/180);
yomega_min = ymin*sin(omega*pi/180);

xlabel('I');
ylabel('J');
zlabel('K');

% plot3([xomega_min xomega_max], [yomega_min yomega_max], [0 0], 'g','Linewidth',1.5);

% add equatorial plan
% xe = [xmin xmax;xmin xmax]; ye = [ymax ymax;ymin ymin]; ze = [0 0; 0 0];
% eq_alpha = 0.3; % transparancy 
% mesh(xe,ye,ze,'FaceAlpha',eq_alpha,'FaceColor',[0.753,0.753,0.753]);

grid on

%% Earth
handles.coe.a = 1.00000011;
handles.coe.e = 0.01671022;
handles.coe.inc = 0.00005;
handles.coe.omega = -11.26064;
handles.coe.w = 102.94719;
handles.coe.v = 100.46435;
handles.coe.r = 0.00465047;

a = handles.coe.a;
e = handles.coe.e;
inc = handles.coe.inc;
omega = handles.coe.omega;
w = handles.coe.w;
v = handles.coe.v;
r = handles.coe.r;

[x,y,z] = orbit(a, e, omega*pi/180, inc*pi/180, w*pi/180);
[xv,yv,zv] = trueanomaly(a,e,omega*pi/180,inc*pi/180,w*pi/180,v*pi/180);
[xp,yp,zp] = planet(r,20); % earth radius ( km )

plot3(x,y,z,'Color',orbit_color,'Linewidth',2); % direct

axis equal
hold on

plot3(xv,yv,zv,'Color',[0,0.5,0],'MarkerFaceColor',[0,0.5,0],'Marker','o','Linewidth',2); % plot true anomaly
surf(xp,yp,zp,'EdgeAlpha',0.4);   % plot the planet
colormap([0  0.5  0]);

scale = 2;
axis([-scale*a scale*a -scale*a scale*a -scale*a scale*a])


% Get Axis properties 
axis_data = get(gca);
xmin = axis_data.XLim(1);
xmax = axis_data.XLim(2);
ymin = axis_data.YLim(1);
ymax = axis_data.YLim(2);
zmin = axis_data.ZLim(1);
zmax = axis_data.ZLim(2);

% I, J ,K vectors
% plot3([xmin,xmax],[0 0],[0 0],'black','Linewidth',1); plot3(xmax,0,0,'black>','Linewidth',1.5);
% plot3([0 0],[ymin,ymax],[0 0],'black','Linewidth',1); plot3(0,ymax,0,'blue>','Linewidth',1.5);
% plot3([0 0],[0 0],[zmin,zmax],'black','Linewidth',1); plot3(0,0,zmax,'red^','Linewidth',1.5);

% right ascending node line plot
xomega_max = xmax*cos(omega*pi/180);
xomega_min = xmin*cos(omega*pi/180);
yomega_max = ymax*sin(omega*pi/180);
yomega_min = ymin*sin(omega*pi/180);

xlabel('I');
ylabel('J');
zlabel('K');

% plot3([xomega_min xomega_max], [yomega_min yomega_max], [0 0], 'g','Linewidth',1.5);

% add equatorial plan
% xe = [xmin xmax;xmin xmax]; ye = [ymax ymax;ymin ymin]; ze = [0 0; 0 0];
% eq_alpha = 0.3; % transparancy 
% mesh(xe,ye,ze,'FaceAlpha',eq_alpha,'FaceColor',[0.753,0.753,0.753]);

grid on

%% Mars
handles.coe.a = 1.52366231;
handles.coe.e = 0.09341233;
handles.coe.inc = 1.85061;
handles.coe.omega = 49.57854;
handles.coe.w = 336.04084;
handles.coe.v = 355.45332;
handles.coe.r = 0.00465047;

a = handles.coe.a;
e = handles.coe.e;
inc = handles.coe.inc;
omega = handles.coe.omega;
w = handles.coe.w;
v = handles.coe.v;
r = handles.coe.r;

[x,y,z] = orbit(a, e, omega*pi/180, inc*pi/180, w*pi/180);
[xv,yv,zv] = trueanomaly(a,e,omega*pi/180,inc*pi/180,w*pi/180,v*pi/180);
[xp,yp,zp] = planet(r,20); % earth radius ( km )


plot3(x,y,z,'Color',orbit_color,'Linewidth',2); % direct

axis equal
hold on

plot3(xv,yv,zv,'Color',[0,0.5,0],'MarkerFaceColor',[0,0.5,0],'Marker','o','Linewidth',2); % plot true anomaly
surf(xp,yp,zp,'EdgeAlpha',0.4);   % plot the planet
colormap([0  0.5  0]);

scale = 2;
axis([-scale*a scale*a -scale*a scale*a -scale*a scale*a])


% Get Axis properties 
axis_data = get(gca);
xmin = axis_data.XLim(1);
xmax = axis_data.XLim(2);
ymin = axis_data.YLim(1);
ymax = axis_data.YLim(2);
zmin = axis_data.ZLim(1);
zmax = axis_data.ZLim(2);

% I, J ,K vectors
% plot3([xmin,xmax],[0 0],[0 0],'black','Linewidth',1); plot3(xmax,0,0,'k>','Linewidth',1.5);
% plot3([0 0],[ymin,ymax],[0 0],'black','Linewidth',1); plot3(0,ymax,0,'k>','Linewidth',1.5);
% plot3([0 0],[0 0],[zmin,zmax],'black','Linewidth',1); plot3(0,0,zmax,'k^','Linewidth',1.5);

% right ascending node line plot
xomega_max = xmax*cos(omega*pi/180);
xomega_min = xmin*cos(omega*pi/180);
yomega_max = ymax*sin(omega*pi/180);
yomega_min = ymin*sin(omega*pi/180);

xlabel('I');
ylabel('J');
zlabel('K');

% plot3([xomega_min xomega_max], [yomega_min yomega_max], [0 0], 'g','Linewidth',1.5);

% add equatorial plan
% xe = [xmin xmax;xmin xmax]; ye = [ymax ymax;ymin ymin]; ze = [0 0; 0 0];
% eq_alpha = 0.3; % transparancy 
% mesh(xe,ye,ze,'FaceAlpha',eq_alpha,'FaceColor',[0.753,0.753,0.753]);

grid on

%% Jupiter
handles.coe.a = 5.20336301;
handles.coe.e = 0.04839266;
handles.coe.inc = 1.30530;
handles.coe.omega = 100.55615;
handles.coe.w = 14.75385;
handles.coe.v = 34.40438;
handles.coe.r = 0.00465047;

a = handles.coe.a;
e = handles.coe.e;
inc = handles.coe.inc;
omega = handles.coe.omega;
w = handles.coe.w;
v = handles.coe.v;
r = handles.coe.r;

[x,y,z] = orbit(a, e, omega*pi/180, inc*pi/180, w*pi/180);
[xv,yv,zv] = trueanomaly(a,e,omega*pi/180,inc*pi/180,w*pi/180,v*pi/180);
[xp,yp,zp] = planet(r,20); % earth radius ( km )


plot3(x,y,z,'Color',orbit_color,'Linewidth',2); % direct

axis equal
hold on

plot3(xv,yv,zv,'Color',[0,0.5,0],'MarkerFaceColor',[0,0.5,0],'Marker','o','Linewidth',2); % plot true anomaly
surf(xp,yp,zp,'EdgeAlpha',0.4);   % plot the planet
colormap([0  0.5  0]);

scale = 2;
axis([-scale*a scale*a -scale*a scale*a -scale*a scale*a])


% Get Axis properties 
axis_data = get(gca);
xmin = axis_data.XLim(1);
xmax = axis_data.XLim(2);
ymin = axis_data.YLim(1);
ymax = axis_data.YLim(2);
zmin = axis_data.ZLim(1);
zmax = axis_data.ZLim(2);

% I, J ,K vectors
plot3([xmin,xmax],[0 0],[0 0],'black','Linewidth',1); plot3(xmax,0,0,'k>','Linewidth',1.5);
plot3([0 0],[ymin,ymax],[0 0],'black','Linewidth',1); plot3(0,ymax,0,'k>','Linewidth',1.5);
plot3([0 0],[0 0],[zmin,zmax],'black','Linewidth',1); plot3(0,0,zmax,'k^','Linewidth',1.5);

% right ascending node line plot
xomega_max = xmax*cos(omega*pi/180);
xomega_min = xmin*cos(omega*pi/180);
yomega_max = ymax*sin(omega*pi/180);
yomega_min = ymin*sin(omega*pi/180);

xlabel('I');
ylabel('J');
zlabel('K');

% plot3([xomega_min xomega_max], [yomega_min yomega_max], [0 0], 'g','Linewidth',1.5);

% add equatorial plan
% xe = [xmin xmax;xmin xmax]; ye = [ymax ymax;ymin ymin]; ze = [0 0; 0 0];
% eq_alpha = 0.3; % transparancy 
% mesh(xe,ye,ze,'FaceAlpha',eq_alpha,'FaceColor',[0.753,0.753,0.753]);

grid on

end
